@@ -11,6 +11,7 @@ pub enum Values {
     U8(Vec<u8>),
     U32(Vec<u32>),
     U64(Vec<u64>),
+    I8(Vec<i8>),
     I32(Vec<i32>),
     I64(Vec<i64>),
     F32(Vec<f32>),
@@ -25,6 +26,7 @@ impl List {
             Values::U8(values) => format!("List(U8({:?}))", values),
             Values::U32(values) => format!("List(U32({:?}))", values),
             Values::U64(values) => format!("List(U64({:?}))", values),
+            Values::I8(values) => format!("List(I8({:?}))", values),
             Values::I32(values) => format!("List(I32({:?}))", values),
             Values::I64(values) => format!("List(I64({:?}))", values),
             Values::F32(values) => format!("List(F32({:?}))", values),
