@@ -13,9 +13,11 @@ pub enum Stage {
     Filter {
         expr: FilterExpr,
     },
-    TopK {
-        expr: LogicalExpr,
+    Limit {
         k: u64,
+    },
+    Sort {
+        expr: LogicalExpr,
         asc: bool,
     },
     Count {},
@@ -32,9 +34,8 @@ impl From<Stage> for topk_rs::proto::v1::data::Stage {
         match stage {
             Stage::Select { exprs } => topk_rs::proto::v1::data::Stage::select(exprs),
             Stage::Filter { expr } => topk_rs::proto::v1::data::Stage::filter(expr),
-            Stage::TopK { expr, k, asc } => {
-                topk_rs::proto::v1::data::Stage::topk(expr.into(), k, asc)
-            }
+            Stage::Limit { k } => topk_rs::proto::v1::data::Stage::limit(k),
+            Stage::Sort { expr, asc } => topk_rs::proto::v1::data::Stage::sort(expr.into(), asc),
             Stage::Count {} => topk_rs::proto::v1::data::Stage::count(),
             Stage::Rerank {
                 model,
