@@ -35,6 +35,31 @@ def test_delete_document(ctx: ProjectContext):
     assert doc_ids(docs) == {"two"}
 
 
+def test_delete_with_filter(ctx: ProjectContext):
+    collection = ctx.client.collections().create(ctx.scope("test"), schema={})
+
+    lsn = ctx.client.collection(collection.name).upsert(
+        [
+            {"_id": "one", "rank": 1},
+            {"_id": "two", "rank": 2},
+            {"_id": "three", "rank": 3},
+        ]
+    )
+    assert lsn == "1"
+
+    # wait for write to be flushed
+    ctx.client.collection(collection.name).count()
+
+    lsn = ctx.client.collection(collection.name).delete(field("rank") != 2)
+    assert lsn == "2"
+
+    docs = ctx.client.collection(collection.name).query(
+        select("title").topk(field("rank"), 100, True), lsn=lsn
+    )
+
+    assert doc_ids(docs) == {"two"}
+
+
 def test_delete_non_existent_document(ctx: ProjectContext):
     collection = ctx.client.collections().create(ctx.scope("test"), schema={})
 
