@@ -29,10 +29,18 @@ def test_get_document(ctx: ProjectContext):
             "published_year": 1954,
             "summary": "A group of unlikely heroes sets out to destroy a powerful, evil ring.",
             "summary_embedding": [9.0] * 16,
+            "scalar_i8_embedding": [-100] * 16,
             "sparse_f32_embedding": {9: 1.0, 10: 2.0, 11: 3.0},
             "sparse_u8_embedding": {9: 1, 10: 2, 11: 3},
             "tags": ["lord of the rings", "fellowship", "magic", "wizard", "elves"],
-            "codes": ["ISBN 978-0-547-92821-0", "ISBN 0-547-92821-2", "OCLC 434394005", "LCCN 2004558654", "Barcode 0618346252"],
+            "codes": [
+                "ISBN 978-0-547-92821-0",
+                "ISBN 0-547-92821-2",
+                "OCLC 434394005",
+                "LCCN 2004558654",
+                "Barcode 0618346252",
+            ],
+            "user_ratings": ["epic", "legendary", "good"],
         }
     }
 
@@ -49,11 +57,18 @@ def test_get_multiple_documents(ctx: ProjectContext):
             "published_year": 1954,
             "summary": "A group of unlikely heroes sets out to destroy a powerful, evil ring.",
             "summary_embedding": [9.0] * 16,
+            "scalar_i8_embedding": [-100] * 16,
             "sparse_f32_embedding": {9: 1.0, 10: 2.0, 11: 3.0},
             "sparse_u8_embedding": {9: 1, 10: 2, 11: 3},
             "tags": ["lord of the rings", "fellowship", "magic", "wizard", "elves"],
-            "codes": ["ISBN 978-0-547-92821-0", "ISBN 0-547-92821-2", "OCLC 434394005", "LCCN 2004558654", "Barcode 0618346252"],
-
+            "codes": [
+                "ISBN 978-0-547-92821-0",
+                "ISBN 0-547-92821-2",
+                "OCLC 434394005",
+                "LCCN 2004558654",
+                "Barcode 0618346252",
+            ],
+            "user_ratings": ["epic", "legendary", "good"],
         },
         "moby": {
             "_id": "moby",
@@ -67,6 +82,7 @@ def test_get_multiple_documents(ctx: ProjectContext):
             "tags": ["whale", "obsession", "tragedy", "sailing", "ocean"],
             "codes": [],
             "reprint_years": [],
+            "user_ratings": [-5, 2, -1, 1],
         },
     }
 
