@@ -64,6 +64,31 @@ def test_upsert_schema_validation(ctx: ProjectContext):
     assert "MissingField" in str(exc_info.value)
 
 
+def test_upsert_max_doc_size(ctx: ProjectContext):
+    collection = ctx.client.collections().create(ctx.scope("test"), schema={})
+
+    with pytest.raises(error.DocumentValidationError) as exc_info:
+        ctx.client.collection(collection.name).upsert(
+            [
+                {"_id": "one", "payload": "x" * (500 * 1024)},  # 500KB, too large
+                {"_id": "two", "payload": "xxx"},  # ok
+                {"_id": "three", "payload": "x" * (130 * 1024)},  # 130KB, too large
+                {
+                    "_id": "four",
+                    "payload": "x" * (126 * 1024),
+                },  # 126KB (plus overhead), ok
+            ]
+        )
+
+    s = str(exc_info.value)
+    assert s.count("DocumentTooLarge") == 2
+    assert 'doc_id: "one"' in s
+    assert 'doc_id: "three"' in s
+    assert 'doc_id: "two"' not in s
+    assert 'doc_id: "four"' not in s
+    assert "max_size_bytes: 131072" in s
+
+
 @pytest.mark.parametrize(
     "params",
     [
@@ -208,15 +233,14 @@ def test_upsert_sparse_vectors(ctx: ProjectContext):
     assert obj["x"]["u8_sparse_vector"][2] == 5
     assert obj["x"]["u8_sparse_vector"][3] == 6
 
+
 def test_upsert_empty_float_list(ctx: ProjectContext):
     collection = ctx.client.collections().create(
         ctx.scope("test"),
         schema={"f32_list": schema.list(value_type="float")},
     )
 
-    lsn = ctx.client.collection(collection.name).upsert(
-        [{"_id": "x", "f32_list": []}]
-    )
+    lsn = ctx.client.collection(collection.name).upsert([{"_id": "x", "f32_list": []}])
 
     obj = ctx.client.collection(collection.name).get(["x"], lsn=lsn)
 
@@ -245,14 +269,14 @@ def test_upsert_empty_integer_list_raises_error(ctx: ProjectContext):
     )
 
     with pytest.raises(error.DocumentValidationError) as exc_info:
-        ctx.client.collection(collection.name).upsert(
-            [{"_id": "x", "i32_list": []}]
-        )
-    assert "field: \"i32_list\", expected_type: \"list<integer>\", got_value: \"list<f32>\"" in str(exc_info.value)
+        ctx.client.collection(collection.name).upsert([{"_id": "x", "i32_list": []}])
+    assert (
+        'field: "i32_list", expected_type: "list<integer>", got_value: "list<f32>"'
+        in str(exc_info.value)
+    )
 
 
 def test_upsert_empty_integer_list_with_helper(ctx: ProjectContext):
-
     collection = ctx.client.collections().create(
         ctx.scope("test"),
         schema={"i32_list": schema.list(value_type="integer")},
@@ -274,11 +298,12 @@ def test_upsert_empty_string_list_raises_error(ctx: ProjectContext):
     )
 
     with pytest.raises(error.DocumentValidationError) as exc_info:
-        ctx.client.collection(collection.name).upsert(
-        [{"_id": "x", "string_list": []}]
-    )
+        ctx.client.collection(collection.name).upsert([{"_id": "x", "string_list": []}])
 
-    assert "field: \"string_list\", expected_type: \"list<string>\", got_value: \"list<f32>\"" in str(exc_info.value)
+    assert (
+        'field: "string_list", expected_type: "list<string>", got_value: "list<f32>"'
+        in str(exc_info.value)
+    )
 
 
 def test_upsert_empty_string_list_with_helper(ctx: ProjectContext):
@@ -293,4 +318,4 @@ def test_upsert_empty_string_list_with_helper(ctx: ProjectContext):
 
     obj = ctx.client.collection(collection.name).get(["x"], lsn=lsn)
 
-    assert obj["x"]["string_list"] == []
\ No newline at end of file
+    assert obj["x"]["string_list"] == []
