@@ -3,6 +3,7 @@ use crate::proto::data::v1::list;
 mod document;
 mod sparse_vector;
 mod value;
+use bytemuck::allocation::cast_vec;
 
 pub trait IntoListValues {
     fn into_list_values(self) -> list::Values;
@@ -26,6 +27,14 @@ impl IntoListValues for Vec<u64> {
     }
 }
 
+impl IntoListValues for Vec<i8> {
+    fn into_list_values(self) -> list::Values {
+        // Transmute to u8 and use `bytes` in proto because it doesn't have an i8 type
+        let u8_vec = cast_vec(self);
+        list::Values::I8(list::I8 { values: u8_vec })
+    }
+}
+
 impl IntoListValues for Vec<i32> {
     fn into_list_values(self) -> list::Values {
         list::Values::I32(list::I32 { values: self })
