@@ -27,7 +27,8 @@ impl Query {
     }
 
     pub fn topk(mut self, expr: LogicalExpr, k: u64, asc: bool) -> Self {
-        self.stages.push(Stage::topk(expr, k, asc));
+        self.stages.push(Stage::sort(expr, asc));
+        self.stages.push(Stage::limit(k));
         self
     }
 
@@ -47,4 +48,14 @@ impl Query {
             .push(Stage::rerank(model, query, fields, topk_multiple));
         self
     }
+
+    pub fn limit(mut self, k: u64) -> Self {
+        self.stages.push(Stage::limit(k));
+        self
+    }
+
+    pub fn sort(mut self, expr: LogicalExpr, asc: bool) -> Self {
+        self.stages.push(Stage::sort(expr, asc));
+        self
+    }
 }
