@@ -2,6 +2,7 @@ use test_context::test_context;
 use topk_rs::doc;
 use topk_rs::query::{field, filter};
 use topk_rs::Error;
+use topk_rs::schema;
 
 mod utils;
 use utils::dataset;
@@ -20,6 +21,26 @@ async fn test_query_non_existent_collection(ctx: &mut ProjectTestContext) {
     assert!(matches!(err, Error::CollectionNotFound));
 }
 
+#[test_context(ProjectTestContext)]
+#[tokio::test]
+async fn test_query_count_empty_collection(ctx: &mut ProjectTestContext) {
+    let collection: topk_rs::proto::v1::control::Collection = ctx
+        .client
+        .collections()
+        .create(ctx.wrap("empty"), schema!())
+        .await
+        .expect("could not create collection");
+
+    let count  = ctx
+        .client
+        .collection(collection.name)
+        .count(None, Some(topk_rs::proto::v1::data::ConsistencyLevel::Strong))
+        .await
+        .expect("could not query");
+
+    assert_eq!(count, 0)
+}
+
 #[test_context(ProjectTestContext)]
 #[tokio::test]
 async fn test_query_count(ctx: &mut ProjectTestContext) {
